/*
 *
 * Copyright (c) 2001
 *	Politecnico di Torino.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that: (1) source code
 * distributions retain the above copyright notice and this paragraph
 * in its entirety, (2) distributions including binary code include
 * the above copyright notice and this paragraph in its entirety in
 * the documentation or other materials provided with the
 * distribution, and (3) all advertising materials mentioning features
 * or use of this software display the following acknowledgment:
 * ``This product includes software developed by the Politecnico di Torino
 * Telecomunication Networking Group.''
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * 
 * Author:	Marco Mellia, Andrea Carpani
 * 		Telecomunication Networks Group
 * 		Politecnico di Torino
 * 		Torino, Italy
 *              http://http://www.tlc-networks.polito.it/index.html
 *		mellia@mail.tlc.polito.it
 *
 * Tstat is deeply based on TCPTRACE. The authors would like to thank
 * Shawn Ostermann for the development of TCPTRACE.
 * The original TCPTRACE copyright can be found in tcptrace.copyright file.
 *
*/


/* 
 * name.c -- name binding stuff
 * 
 * Author:	Shawn Ostermann
 * Date:	Tue Nov  1, 1994
 */

#include "tstat.h"


/* local routines */


char *
ServiceName (portnum port)
{
  static char port_buf[6];

  sprintf (port_buf, "%hu", port);
  return (port_buf);
}


/* turn an ipaddr into a printable format */
/* N.B. - result comes from static memory, save it before calling back! */
char *
HostAddr (ipaddr ipaddress)
{
  char *adr;

#ifdef SUPPORT_IPV6
  if (ADDR_ISV6 (&ipaddress))
    {
      static char adrv6[INET6_ADDRSTRLEN];
      my_inet_ntop (AF_INET6, (char *) ipaddress.un.ip6.s6_addr,
		    adrv6, INET6_ADDRSTRLEN);
      adr = adrv6;
    }
  else
#endif
      adr = inet_ntoa (ipaddress.un.ip4);

  return (adr);
}



char *
HostName (ipaddr ipaddress)
{
  char *adr;

  adr = HostAddr (ipaddress);
  return (adr);
}



char *
EndpointName (ipaddr ipaddress, portnum port)
{
  static char name_buf[100];
  char *sb_host;
  char *sb_port;

  sb_host = HostName (ipaddress);
  sb_port = ServiceName (port);

  sprintf (name_buf, "%s:%s", sb_host, sb_port);

  return (name_buf);
}
